### 開始使用

PDFMathTranslate 是一個強大的 PDF 翻譯工具。您可以通過多種方式安裝並開始使用此工具。

---

### 如何安裝

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>推薦用於 Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>推薦用於 Linux</small>
3. [**uv** (a Python package manager)](./INSTALLATION_uv.md) <small>推薦用於 macOS</small>

---

### 如何使用

1. [使用 **WebUI**](./USAGE_webui.md)
2. [使用 **Zotero 插件**](https://github.com/guaguastandup/zotero-pdf2zh) (第三方程序)
3. [使用 **命令行**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Some content on this page has been translated by GPT and may contain errors.</small></h6>